#if !defined(INCLUDED_SLEPCCONF_H)
#define INCLUDED_SLEPCCONF_H

#define SLEPC_PETSC_DIR "/clangarm64/src/petsc"
#define SLEPC_PETSC_ARCH "zto"
#define SLEPC_DIR "/c/W/B/src/build-CLANGARM64/slepc-3.23.3"
#define SLEPC_LIB_DIR "/c/W/B/src/build-CLANGARM64/slepc-3.23.3/zto/lib"
#define SLEPC_HAVE_PACKAGES ":"
#endif
